﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WinForms;

namespace ChildMap
{
    public partial class Map : Form
    {
        public Map()
        {
            InitializeComponent();

            this.Dock = DockStyle.Fill;

            winformsMap1.MapUnit = ThinkGeo.MapSuite.GeographyUnit.Meter;

            Proj4Projection proj = new Proj4Projection(32615, 32615);

            InMemoryFeatureLayer imfl = new InMemoryFeatureLayer();
            imfl.Name = "Test";
            imfl.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = new AreaStyle(new GeoPen(GeoColor.StandardColors.Black, 3));
            imfl.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            imfl.FeatureSource.Projection = proj;

            RectangleShape rect = new RectangleShape(new PointShape(0, 10000), new PointShape(5000, 0));

            imfl.InternalFeatures.Add(new Feature(rect));

            LayerOverlay lo = new LayerOverlay();
            lo.Name = "Overlay";
            lo.Layers.Add("Layer", imfl);

            winformsMap1.Overlays.Add("Overlay", lo);

            winformsMap1.CurrentExtent = rect;

            BuildLegend("Title");

            winformsMap1.Refresh();
        }

        public void BuildLegend(string name)
        {

            // Create the LegendAdornmentLayer and add the LegendItems.
            LegendAdornmentLayer legendLayer = new LegendAdornmentLayer();
            legendLayer.Location = AdornmentLocation.UpperRight;
            legendLayer.Width = 160;
            legendLayer.Title = new LegendItem(160, 30 * 2, 30, 30, null,
                new TextStyle(name, new GeoFont("Arial", 12),
                new GeoSolidBrush(GeoColor.SimpleColors.Black)));
            legendLayer.Title.TextLeftPadding = -25;
            legendLayer.Title.TextTopPadding = 5;

            GeoColor start = GeoColor.StandardColors.Red;
            GeoColor end = GeoColor.StandardColors.Blue;

            int breaks = 25;
            Collection<GeoColor> colors = GeoColor.GetColorsInQualityFamily(start, end, breaks, ColorWheelDirection.Clockwise);

            legendLayer.Height = winformsMap1.Height;

            for (int i = 0; i < breaks; i++)
            {
                LegendItem legendItem = new LegendItem();
                AreaStyle areaStyle = new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(100, colors[i])));
                legendItem.ImageStyle = areaStyle;

                legendItem.ImageWidth = 30 + 1;
                legendItem.Width = 30 + 1;

                int size = Convert.ToInt32(Math.Floor((winformsMap1.Height - legendLayer.Title.Height - 35) / breaks));
                double fsize = (winformsMap1.Height - legendLayer.Title.Height - 35) / breaks;

                if (size >= 30)
                {
                    size = 30;
                    fsize = 30;
                    legendLayer.Height = legendLayer.Title.Height + (breaks * 30) + 35;
                }
                else
                    legendLayer.Height = winformsMap1.Height;

                legendItem.ImageHeight = (float)fsize;
                legendItem.Height = (float)fsize;

                string title = "";
                if (i == 0)
                    title = string.Format("<{0}", i);
                else if (i < breaks)
                    title = string.Format("{0} - {1}", i - 1, i);
                else
                    title = string.Format(">{0}", i);

                legendItem.TextStyle = new TextStyle(title, new GeoFont("Arial", 8),
                   new GeoSolidBrush(GeoColor.SimpleColors.Black));
                legendItem.TextTopPadding = Convert.ToInt32(fsize / 2f);

                legendLayer.LegendItems.Add(legendItem);
            }

            legendLayer.BackgroundMask = AreaStyles.CreateLinearGradientStyle(GeoColor.StandardColors.LightGray,
                GeoColor.StandardColors.White, 45, GeoColor.SimpleColors.Black);

            // Remove the old legend.
            if (winformsMap1.AdornmentOverlay.Layers.Count > 0)
                winformsMap1.AdornmentOverlay.Layers.Remove("LegendLayer");
            winformsMap1.AdornmentOverlay.Layers.Add("LegendLayer", legendLayer);
            winformsMap1.Refresh();

        }

        private void winformsMap1_Resize(object sender, EventArgs e)
        {
            BuildLegend("Title");
        }
    }
}
